@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/GaussianData.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -274,7 +274,8 @@ void GaussianData::input(std::ifstream & fi) {
 // input
 //------
 void GaussianData::input(const DataDescription & dataDescription) {
-	double* curSampleValue = new double[_pbDimension];
+  //double* curSampleValue = new double[_pbDimension];
+  std::unique_ptr<double[]> curSampleValue(new double[_pbDimension]);    
 	_weightTotal = 0.0;
 
 	_fileNameData = dataDescription.getFileName();
@@ -325,18 +326,18 @@ void GaussianData::input(const DataDescription & dataDescription) {
 				}
 			}
 		}
-		_matrix[i]->getGaussianSample()->setDataTabValue(curSampleValue);
+		_matrix[i]->getGaussianSample()->setDataTabValue(curSampleValue.get());
 		_weightTotal += _weight[i];
 	}
 
-	delete [] curSampleValue;
+	//delete [] curSampleValue;
 }
 
 // output
 //-------
 void GaussianData::output(std::ostream & fo) {
 	
-	if (VERBOSE) {
+	if (VERBOSE == 1) {
 		cout << "Sample size: " << _nbSample << endl;
 		cout << "  Dimension: " << _pbDimension << endl;
 	}
