@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/ProbaOutput.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -85,17 +85,21 @@ ProbaOutput::ProbaOutput(Model * model) {
 
 		//label et partition on reduceData
 		int64_t nbSampleOfDataReduce = model->getNbSample();
-		int64_t ** tabPartitionReduce = new int64_t*[nbSampleOfDataReduce];
+		//int64_t ** tabPartitionReduce = new int64_t*[nbSampleOfDataReduce];
+        std::unique_ptr<int64_t*[], TabDeleter<int64_t>>  tabPartitionReduce(new int64_t*[nbSampleOfDataReduce],
+                                                                             TabDeleter<int64_t>(nbSampleOfDataReduce));
 		for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
 			tabPartitionReduce[i] = new int64_t[_nbCluster];
 		}
-		int64_t * tabLabelReduce = new int64_t[nbSampleOfDataReduce];
-		model->getLabelAndPartitionByMAPOrKnownPartition(tabLabelReduce, tabPartitionReduce);
+		//int64_t * tabLabelReduce = new int64_t[nbSampleOfDataReduce];
+        std::unique_ptr<int64_t[]> tabLabelReduce(new int64_t[nbSampleOfDataReduce]);
+		model->getLabelAndPartitionByMAPOrKnownPartition(tabLabelReduce.get(), tabPartitionReduce.get());
 
-		double ** tabPostProbaReduce = NULL;
+		//double ** tabPostProbaReduce = NULL;
 		// copy
-		tabPostProbaReduce = copyTab(model->getPostProba(), nbSampleOfDataReduce, _nbCluster);
-
+		//tabPostProbaReduce = copyTab(model->getPostProba(), nbSampleOfDataReduce, _nbCluster);
+        std::unique_ptr<double*[], TabDeleter<double>>  tabPostProbaReduce(copyTab(model->getPostProba(), nbSampleOfDataReduce, _nbCluster),
+                                                                           TabDeleter<double>(nbSampleOfDataReduce));
 		// convert labelReduce, partitionReduce, postProbaReduce to label, partition, postProba
 		for (int64_t i = 0; i < _nbSample; i++) {
 			_tabLabel[i] = tabLabelReduce[correspondenceOriginDataToReduceData[i]];
@@ -107,17 +111,17 @@ ProbaOutput::ProbaOutput(Model * model) {
 		}
 
 		//delete
-		for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
-			delete [] tabPartitionReduce[i];
-		}
-		delete [] tabPartitionReduce;
+		//for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
+		//	delete [] tabPartitionReduce[i];
+		//}
+		//delete [] tabPartitionReduce;
 
-		for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
-			delete [] tabPostProbaReduce[i];
-		}
-		delete [] tabPostProbaReduce;
+		//for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
+		//	delete [] tabPostProbaReduce[i];
+		//}
+		//delete [] tabPostProbaReduce;
 
-		delete[] tabLabelReduce;
+		//delete[] tabLabelReduce;
 	}
 }
 
