@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryParameter.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -200,7 +200,7 @@ public:
 			double *** scatters);
 
 	// Read Scatter in input file
-	virtual void inputScatter(std::ifstream & fi) = 0;
+	virtual void inputScatter(std::ifstream & fi, int64_t k) = 0;
 	virtual void inputScatter(double *** scatters) = 0;
 
 	/// recopie sans faire construction / destruction
