@@ -1,12 +1,12 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/GaussianHDDAParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
 /***************************************************************************
     This file is part of MIXMOD
-
+    
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org
+    All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
 #include "mixmod/Kernel/Parameter/GaussianHDDAParameter.h"
 #include "mixmod/Kernel/Parameter/GaussianParameter.h"
@@ -471,18 +471,18 @@ double GaussianHDDAParameter::getPdf(Sample * x, int64_t kCluster)const {
 // reads the input data file for HDDA models
 void GaussianHDDAParameter::input(std::ifstream & fi) {
 	int64_t j, k;
-	for (k = 0; k < _nbCluster; k++) {
-		// Proportions //
-		fi >> _tabProportion[k];
-		// Center (mean) //
-		for (j = 0; j < _pbDimension; j++) {
-			fi >> _tabMean[k][j];
-		}
+  for (k = 0; k < _nbCluster; k++) {
+    // Proportions //
+		_tabProportion[k] = getDoubleFromStream(fi);
 
-		// Sub Dimension  //
-		fi >> _tabDk[k];
-		if (_tabAkj[k]) {
-			//cout<<_tabAkj[k][0]<<endl;
+    // Center (mean) //
+    for (j = 0; j < _pbDimension; j++)
+      _tabMean[k][j] = getDoubleFromStream(fi);
+
+    // Sub Dimension  //
+    fi >> _tabDk[k];
+    if (_tabAkj[k]) {
+      //cout<<_tabAkj[k][0]<<endl;
 			//cout<<"ok"<<endl;
 			delete [] _tabAkj[k];
 			_tabAkj[k] = NULL;
@@ -982,9 +982,9 @@ void GaussianHDDAParameter::edit(std::ofstream & oFile, bool text) {
 		}
 		oFile << endl;
 	}
-	else {
-		for (k = 0; k < _nbCluster; k++) {
-			oFile << _tabProportion[k] << endl;
+  else {
+    for (k = 0; k < _nbCluster; k++) {
+			putDoubleInStream(oFile, _tabProportion[k]);
 			editTab(_tabMean + k, 1, _pbDimension, oFile, " ", "");
 			oFile << _tabDk[k] << endl;
 			editTab(_tabAkj + k, 1, _tabDk[k], oFile, " ", "");
