@@ -47,7 +47,6 @@
 #include "mixmod/Utilities/exceptions/NumericException.h"
 #include "mixmod/Utilities/exceptions/OtherException.h"
 
-
 // Need matrix output routines
 #include <vector>
 #include <fstream>
@@ -63,8 +62,13 @@
 #include <assert.h> //For debugging purpose
 
 // Need matrix applications
-#include "mixmod/Utilities/maths/SelectLibrary.h"
+//#include "mixmod/Utilities/maths/SelectLibrary.h"
+#include <cmath>
+#ifndef XEMmathLib
+#define XEMmathLib 1 // default is Eigen
+#endif
 
+using namespace std;
 
 namespace XEM {
 
@@ -830,7 +834,7 @@ template<typename T> void editTab(T ** tab, int64_t dim1, int64_t dim2,
 		flux << before;
 		for (j = 0; j < dim2; j++)
       putDoubleInStream(flux, p_tab_i[j], sep);
-		flux << endl;
+		flux << std::endl;
 		p_tab++;
 	}
 }
